export class ImgproxyService {
    constructor(host) {
        this.host = host;
    }
    generateUrl(imageConfig) {
        // Debug point: Start URL generation
        const processingOptions = this.buildProcessingOptions(imageConfig);
        const path = `/insecure/${processingOptions}/plain/${imageConfig.src}`;
        // Debug point: URL generated
        return `${this.host}${path}`;
    }
    buildProcessingOptions(config) {
        const options = [];
        if (config.width || config.height) {
            options.push(`rs:${config.resizingType || 'auto'}:${config.width || 0}:${config.height || 0}`);
        }
        if (config.gravity) {
            options.push(`g:${config.gravity}`);
        }
        if (config.enlarge) {
            options.push('el:1');
        }
        if (config.extend) {
            options.push('ex:1');
        }
        if (config.format) {
            options.push(`f:${config.format}`);
        }
        if (config.quality) {
            options.push(`q:${config.quality}`);
        }
        return options.join('/');
    }
    isSameUrl(element, newConfig) {
        const currentUrl = element.nodeName === 'IMG'
            ? element.src
            : element.style.backgroundImage?.replace(/^url\(['"](.+)['"]\)$/, '$1');
        const newUrl = this.generateUrl(newConfig);
        return currentUrl === newUrl;
    }
}
//# sourceMappingURL=imgproxy.service.js.map